@@ -35,7 +35,7 @@
 #' lakeMaxDepth(inputLM)             
 
 lakeMaxDepth <- function(inLakeMorpho, slope_quant = 0.5, correctFactor = 1) {
-    if (class(inLakeMorpho) != "lakeMorpho") {
+    if (!inherits(inLakeMorpho, "lakeMorpho")) {
       stop("Input data is not of class 'lakeMorpho'.  Run lakeSurround Topo or lakeMorphoClass first.")
     }
     if(is.null(inLakeMorpho$elev)){
